Learn R Programming

seedreg (version 1.0.3)

curve: Analysis: Logistic regression by treatment over time

Description

Performs the construction of a logistic regression graph by treatment over time

Usage

curve(
  dados,
  trat,
  nrep,
  time,
  n,
  model = LL.3(),
  ylab = "Emergence (%)",
  xlab = "Time (days)",
  legend.position = c(0.2, 0.8)
)

Value

Returns a logistic regression graph by treatment over time.

Arguments

dados

data.frame containing the responses of the evaluations in separate columns side by side and without the columns with the identification of the factors

trat

vector of treatments with n repetitions

nrep

Number of repetitions

time

vector containing time

n

total seeds per repetition

model

logistic model according to drc package

ylab

y-axis name

xlab

x-axis name

legend.position

Legend position

Examples

Run this code
data("substrate")
curve(substrate[,c(3:18)],
      trat = substrate$Trat,
      nrep = 4,
      n=10,
      time = 1:16)

Run the code above in your browser using DataLab