Learn R Programming

seedreg (version 1.0.3)

seeds: Param: Seeds

Description

Simplification of functions: acc, iv, tm and tml.

Usage

seeds(data, trat, nrep, time)

Value

Returns a data.frame with the indices

Arguments

data

Data.frame containing the responses of the evaluations in separate columns side by side and without the columns with the identification of the factors

trat

Vector of treatments with n repetitions

nrep

Number of repetitions

time

Vector containing time

Examples

Run this code
data("substrate")
seeds(substrate[,c(3:18)],
      trat = substrate$Trat,
      nrep = 4,
      time = 1:16)

Run the code above in your browser using DataLab