powered by
Performs the construction of a logistic regression graph by treatment over time
curve( dados, trat, nrep, time, n, model = LL.3(), ylab = "Emergence (%)", xlab = "Time (days)", legend.position = c(0.2, 0.8) )
Returns a logistic regression graph by treatment over time.
data.frame containing the responses of the evaluations in separate columns side by side and without the columns with the identification of the factors
vector of treatments with n repetitions
Number of repetitions
vector containing time
total seeds per repetition
logistic model according to drc package
y-axis name
x-axis name
Legend position
data("substrate") curve(substrate[,c(3:18)], trat = substrate$Trat, nrep = 4, n=10, time = 1:16)
Run the code above in your browser using DataLab