powered by
Simplification of functions: acc, iv, tm and tml.
seeds(data, trat, nrep, time)
Returns a data.frame with the indices
Data.frame containing the responses of the evaluations in separate columns side by side and without the columns with the identification of the factors
Vector of treatments with n repetitions
Number of repetitions
Vector containing time
data("substrate") seeds(substrate[,c(3:18)], trat = substrate$Trat, nrep = 4, time = 1:16)
Run the code above in your browser using DataLab